package App::Scaffolder::Puppet;
{
  $App::Scaffolder::Puppet::VERSION = '0.001000';
}

# ABSTRACT: App::Scaffolder extension to scaffold Puppet modules

use strict;
use warnings;


1;


__END__
=pod

=head1 NAME

App::Scaffolder::Puppet - App::Scaffolder extension to scaffold Puppet modules

=head1 VERSION

version 0.001000

=head1 DESCRIPTION

App::Scaffolder::Puppet provides a command to scaffold Puppet modules. See
L<App::Scaffolder::Command::puppetmodule|App::Scaffolder::Command::puppetmodule>
for the actual command.

=head1 SEE ALSO

=over

=item *

L<App::Scaffolder|App::Scaffolder>

=back

=head1 AUTHOR

Manfred Stock <mstock@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Manfred Stock.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

